@@ -4,6 +4,7 @@ use warnings;
 use strict;
 use CGI::Application::Plugin::Forward;
 use Carp;
+use UNIVERSAL::require;
 use base qw(Exporter);
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS);
 # Items to export into callers namespace by default. Note: do not export
@@ -34,11 +35,11 @@ CGI::Application::Plugin::PageLookup - Database driven model framework for CGI::
 
 =head1 VERSION
 
-Version 1.1
+Version 1.2
 
 =cut
 
-our $VERSION = '1.1';
+our $VERSION = '1.2';
 
 =head1 DESCRIPTION
 
@@ -453,6 +454,7 @@ sub pagelookup {
 	}
 	else {
 		$object = eval {
+			$ovalue->require;
 			return $ovalue->new($self, $page_id, $template, $okey, @inargs);
 		};
 		croak "Could not create smart object: $okey: $@" if $@;
